from setuptools import setup

setup (name="iqsylani46214",
version="0.1",
description="this is a package created by iqbal",
long_description="this is a very very long description created by iqbal",
author = "Iqbal Ahmed",
packages = ["iqsylani46214"],
install_packages = []
)